@@ -9,7 +9,8 @@ headers = {
     "Content-Type": "application/json",
 }
 
-endpoint = 'http://0.0.0.0:65481/api/search'
+endpoint = "http://0.0.0.0:45678/api/search"
+
 
 class Encoder:
     def img_base64(byte_string):
@@ -37,11 +38,12 @@ class Getter:
         data = '{"top_k":' + str(top_k) + ', "mode": "search", "data":' + query + "}"
         response = requests.post(endpoint, headers=headers, data=data)
 
-        content = response.json()["search"]["docs"][0]["topkResults"]
+        content = response.json()["search"]["docs"]
         results = []
         for doc in content:
-            img = doc["matchDoc"]["uri"]
-            results.append(img)
+            matches = doc["matches"]
+            for match in matches:
+                results.append(match["uri"])
 
         return results
 
@@ -52,11 +54,10 @@ class Getter:
         content = response.json()["search"]["docs"]
         results = []
         for doc in content:
-            matches = doc["matches"] #list
+            matches = doc["matches"]  # list
             for match in matches:
                 results.append(match["text"])
 
-
         return results
 
 
@@ -82,6 +83,7 @@ class Renderer:
 
         return output
 
+
 class text:
     class results:
         def markdown(query, top_k, endpoint):
@@ -93,6 +95,7 @@ class text:
             raw_results = Getter.text(query, top_k, endpoint)
             return raw_results
 
+
 class image:
     class results:
         def render(query, top_k, endpoint):
@@ -101,35 +104,19 @@ class image:
             output = Renderer.images(results)
             return st.markdown(output, unsafe_allow_html=True)
 
-# class canvas:
-    # def encoder(data):
-        # if data is not None:
-            # if data.image_data is not None:
-                # img_data = data.image_data
-                # im = Image.fromarray(img_data.astype("uint8"), mode="RGBA")
-                # buffered = BytesIO()
-                # im.save(buffered, format="PNG")
-                # img_str = base64.b64encode(buffered.getvalue())
-                # output = str(img_str)[2:-1]
-                # encoded_query = f'["data:image/png;base64,{output}"]'
-                # output = Renderer.images(encoded_query)
-
-        # return encoded_query
-
 
 class jina:
     def text_search(endpoint="", top_k=10, output="raw", hidden=[]):
         container = st.beta_container()
         with container:
-            # Show input widgets
             if "endpoint" not in hidden:
-                endpoint = st.text_input("Endpoint", "http://0.0.0.0:65481/api/search")
+                endpoint = st.text_input("Endpoint", "http://0.0.0.0:45678/api/search")
             else:
                 endpoint = endpoint
 
             query = st.text_input("Enter query")
             if "top_k" not in hidden:
-                top_k = st.slider("Results", 1, top_k, int(top_k/2))
+                top_k = st.slider("Results", 1, top_k, int(top_k / 2))
             else:
                 top_k = top_k
             button = st.button("Search")
@@ -138,11 +125,12 @@ class jina:
                 if output == "markdown":
                     text.results.markdown(endpoint=endpoint, query=query, top_k=top_k)
                 elif output == "raw":
-                    st.write(text.results.raw(endpoint=endpoint, query=query, top_k=top_k))
+                    st.write(
+                        text.results.raw(endpoint=endpoint, query=query, top_k=top_k)
+                    )
 
         return container
 
-
     def image_search(endpoint="", top_k=10, hidden=[]):
         container = st.beta_container()
         with container:
@@ -155,7 +143,7 @@ class jina:
             query = st.file_uploader("Upload file")
 
             if "top_k" not in hidden:
-                top_k = st.slider("Results", 1, top_k, int(top_k/2))
+                top_k = st.slider("Results", 1, top_k, int(top_k / 2))
             else:
                 top_k = top_k
             button = st.button("Search")
